R/createTonnageString.R
createTonnageString.Rdinputs to get_ functions are required as strings when passed as a sql statement This function converts numeric inputs to character strings. Used specifically for tonnage class
createTonnageString(itemName, chosenItem)A character string
if (FALSE) { # \dontrun{
createTonnageString(itemName="toncl2",chosenItem=c(1,2))
createTonnageString(itemName="toncl2",chosenItem="all")
} # }